# --------------------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# --------------------------------------------------------------------------------------------

from knack.help_files import helps

helps['maps'] = """
    type: group
    short-summary: Manage Azure Maps.
"""

helps['maps account'] = """
    type: group
    short-summary: Manage Azure Maps accounts.
"""

helps['maps account keys'] = """
    type: group
    short-summary: Manage Azure Maps account keys.
"""

helps['maps account show'] = """
    type: command
    short-summary: Show the details of a maps account.
"""

helps['maps account list'] = """
    type: command
    short-summary: Show all maps accounts in a subscription or in a resource group.
"""

helps['maps account create'] = """
    type: command
    short-summary: Create a maps account.
    parameters:
        - name: --accept-tos
          short-summary: Accept the Terms of Service, and do not prompt for confirmation.
          long-summary: |
              By creating an Azure Maps account, you agree that you have read and agree to the
              License (https://azure.microsoft.com/en-us/support/legal/) and
              Privacy Statement (https://privacy.microsoft.com/en-us/privacystatement).

"""

helps['maps account update'] = """
    type: command
    short-summary: Update the properties of a maps account.
"""

helps['maps account delete'] = """
    type: command
    short-summary: Delete a maps account.
"""

helps['maps account keys list'] = """
    type: command
    short-summary: List the keys to use with the Maps APIs.
    long-summary: |
        A key is used to authenticate and authorize access to the Maps REST APIs. Only one key is needed at a time; two are given to provide seamless key regeneration.
"""

helps['maps account keys renew'] = """
    type: command
    short-summary: Renew either the primary or secondary key for use with the Maps APIs.
    long-summary: |
        This command immediately invalidates old API keys. Only the renewed keys can be used to connect to maps.
"""



# --------------------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# --------------------------------------------------------------------------------------------

from azure.cli.core.commands import CliCommandType
from azure.cli.command_modules.maps._client_factory import cf_accounts


def load_command_table(self, _):
    mgmt_type = CliCommandType(
        operations_tmpl='azure.mgmt.maps.operations.accounts_operations#AccountsOperations.{}',
        client_factory=cf_accounts)

    with self.command_group('maps account', mgmt_type) as g:
        g.show_command('show', 'get')
        g.custom_command('list', 'list_accounts')
        g.custom_command('create', 'create_account')
        g.command('delete', 'delete')
        g.generic_update_command('update',
                                 getter_name='get',
                                 setter_arg_name='maps_account_create_parameters',
                                 custom_func_name='generic_update_account')

    with self.command_group('maps account keys', mgmt_type) as g:
        g.command('renew', 'regenerate_keys')
        g.command('list', 'list_keys')



# --------------------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# --------------------------------------------------------------------------------------------

from knack.log import get_logger
from knack.prompting import prompt_y_n
from knack.util import CLIError

from azure.mgmt.maps.models import (
    MapsAccountCreateParameters,
    Sku)

ACCOUNT_LOCATION = 'global'

logger = get_logger(__name__)


def create_account(client, resource_group_name, account_name, sku_name='S0', tags=None, force=None):
    terms = 'By creating an Azure Maps account, you agree that you have read and agree to the ' \
            '\nLicense (https://azure.microsoft.com/en-us/support/legal/) and ' \
            '\nPrivacy Statement (https://privacy.microsoft.com/en-us/privacystatement).'
    hint = 'Please select.'
    client_denied_terms = 'You must agree to the License and Privacy Statement to create an account.'

    # Show ToS message to the user
    logger.warning(terms)

    # Prompt yes/no for the user, if --force parameter is not passed in.
    if not force:
        option = prompt_y_n(hint)
        if not option:
            raise CLIError(client_denied_terms)

    # Submit query
    sku = Sku(name=sku_name)
    maps_account_create_params = MapsAccountCreateParameters(location=ACCOUNT_LOCATION, sku=sku, tags=tags)
    return client.create_or_update(resource_group_name, account_name, maps_account_create_params)


def list_accounts(client, resource_group_name=None):
    # Retrieve accounts via subscription
    if resource_group_name is None:
        return client.list_by_subscription()
    # Retrieve accounts via resource group
    return client.list_by_resource_group(resource_group_name)


def generic_update_account(instance, sku_name=None, tags=None):
    # Pre-populate with old instance
    maps_account_create_params = MapsAccountCreateParameters(location=ACCOUNT_LOCATION, sku=instance.sku,
                                                             tags=instance.tags)
    # Update fields with new parameter values
    if sku_name:
        maps_account_create_params.sku.name = sku_name
    if tags:
        maps_account_create_params.tags = tags
    return maps_account_create_params
